<template>
  <div class="mobile-container">
    <van-sticky class="containter-sticky">
      <navBar @clickLeft="onClickLeft" title="设备"></navBar>
    </van-sticky>
    <!--    <div class="search">-->
    <!--      <van-dropdown-menu class="dropdown">-->
    <!--        <van-dropdown-item v-model="param.querys[1].value" :options="option1" style="width: 30%;" @change="onSearch" />-->
    <!--      </van-dropdown-menu>-->
    <!--      <van-search style="width:65%" v-model="param.querys[2].value" placeholder="请输入设备名称" @blur="onSearch" />-->
    <!--    </div>-->
    <van-pull-refresh style="box-sizing: border-box;" v-model="refreshing" @refresh="onRefresh"
                      class="van-hairline--top">
      <van-list :style="{ 'padding-top': refreshing ? 0 : '0.5rem' }" v-model="loading" :finished="finished"
                finished-text="没有更多了" @load="onLoad">
        <div class="table-item" v-for="(item, index) in list" :key="index">
          <div class="title">
            <div>{{ item.deviceName }}</div>
            <div>
              <van-tag v-if="item.resultId" type="success">已巡检</van-tag>
              <van-tag v-if="!item.resultId" color="#999" text-color="#fff">未巡检</van-tag>
            </div>
          </div>
          <div class="two-title">派遣人姓名：{{ item.personName }}</div>
          <div class="two-title">派遣人联系电话：{{ item.personPhone }}</div>
          <div class="card-bottom">
            <div class="two-title">当前状态：
              <van-tag v-if="!item.eventStatus || item.eventStatus == 1" type="success">正常</van-tag>
              <van-tag v-if="item.eventStatus == 2" type="danger">异常</van-tag>
              <van-tag v-if="item.eventStatus == 3" type="primary">已上报</van-tag>
            </div>
            <div class="action">
              <van-button type="info" v-if="item.eventStatus == 2 && !item.warningId" @click="eventReporting(item)"
                          style="margin-right: 10px;">上报异常
              </van-button>
              <template v-if="item.eventStatus < 3 || !item.eventStatus">
                <van-button type="info" v-if="!item.resultId" @click="toDetail(item)">结果录入</van-button>
                <van-button type="info" v-if="item.resultId" @click="toDetail(item)">结果修改</van-button>
              </template>
              <template v-if="item.eventStatus == 3">
                <van-button type="info" @click="toDetail(item)">结果详情</van-button>
              </template>
            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>

  </div>
</template>
<script>
import api from '@/api/device/Inspection.js'
import navBar from '../../components/navBar.vue'
import {Dialog} from 'vant';

export default {
  name: 'AskForLeave',
  components: {navBar},
  data() {
    return {
      value: '',
      value1: '',
      option1: [
        {text: '全部巡检', value: ''},
        {text: '未巡检', value: '0'},
        {text: '已巡检', value: '1'}
      ],
      list: [],
      loading: false,
      finished: false,
      total: 0,
      param: {
        pageBean: {
          page: 1,
          pageSize: 0,
          showTotal: true
        },
        querys: [
          // {
          //   group: "main",
          //   operation: "EQUAL",
          //   parentGroup: "",
          //   property: "d.task_id_",
          //   relation: "AND",
          //   value: ''
          // },
          // {
          //   group: "main",
          //   operation: "EQUAL",
          //   parentGroup: "",
          //   property: "d.task_type_",
          //   relation: "AND",
          //   value: ''
          // },
          // {
          //   group: "main",
          //   operation: "EQUAL",
          //   parentGroup: "",
          //   property: "d.task_id_",
          //   relation: "AND",
          //   value: ''
          // }
        ]
      },
      refreshing: false
    }
  },
  created() {
    if (this.$route.query.id) {
      // this.param.querys[0].value = this.$route.query.id
      window.localStorage.setItem('InspectionPlanId', this.$route.query.id)
    } else {
      // this.param.querys[0].value = window.localStorage.getItem('InspectionPlanId')
    }
  },
  methods: {
    eventReporting(item) {
      Dialog.confirm({
        title: '提示',
        message:
          '确认上报异常事件吗？',
      }).then(() => {
        const toast = this.$toast.loading({
          duration: 0, // 持续展示 toast
          forbidClick: true,
          message: `上报中...`,
        });
        api.eventReporting(item.resultId, res => {
          if (res.state) {
            this.$message.success('上报成功！')
            item.eventStatus = '3'
            this.getData()
          }
          toast.clear()
        })
      })
    },
    onRefresh() {
      setTimeout(() => {
        this.param.pageBean.pageSize = 20
        this.refreshing = true
        this.list = []
        this.getData()
      }, 500)
    },
    onClickLeft() {
      this.$router.go(-1)
    },
    onLoad() {
      setTimeout(() => {
        this.param.pageBean.pageSize += 20
        if (!this.finished) {
          this.getData()
        }
        this.loading = false
      }, 500)
    },
    onSearch() {
      this.param.pageBean.pageSize = 20
      this.finished = false
      this.getData()
    },
    getData() {
      api.getTaskDetailsById(this.param, res => {
        if (res.rows) {
          this.list = res.rows
          this.total = res.total
          if (this.list.length >= this.total) {
            this.finished = true
          }
        } else {
          this.finished = true
        }
        this.refreshing = false
      })
    },
    toDetail(val) {
      console.log(val);

      this.$router.push({name: 'InspectionDetail', query: {id: val.id}, params: {equipment: val}})
    }

  }
}
</script>
<style lang="scss" scoped>
.search {
  width: 100%;
  position: fixed;
  display: flex;
  background-color: #fff;
  justify-content: space-between;
  top: 9vw;
  box-shadow: 0 2px 12px rgba(100, 101, 102, .12);
  z-index: 1;

  .dropdown {
    box-shadow: none;
    width: 30%;
  }
}

.table-item {
  background: #fff;
  box-shadow: 0 0 .5rem .2rem rgba(82, 81, 81, 0.11);
  border-radius: 1rem;
  margin: 1rem .7rem;
  padding: 1rem;
  box-sizing: border-box;

  .title {
    display: flex;
    justify-content: space-between;
    line-height: 3rem;

    div:nth-child(1) {
      font-weight: bold;
    }

  }

  .two-title {
    color: #7e7d7d;
    line-height: 2rem;
  }

  .card-bottom {
    display: flex;
    justify-content: space-between;
    align-items: center;
    color: #7e7d7d;

    .action {
      text-align: right;

      ::v-deep.van-button {
        padding: 8px 40px;
        height: 25PX !important;
      }
    }
  }

}

.mobile-container {
  width: 100%;
  background-color: #f9f9f9 !important;


  // background-color: $--mobile-bg;
  .containter-sticky {
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 200;
  }
}

::v-deep .van-search {
  padding: 0 1rem 0 0;
}

::v-deep .van-dropdown-menu__bar {
  box-shadow: none
}

::v-deep .van-tag {
  position: static;
}
</style>
